package com.hw.ems.record.mapper;

import java.util.List;

import com.hw.ems.record.domain.RecordAlarmData;

/**
 * 异常数据记录Mapper接口
 *
 * @author hw
 * @date 2023-04-21
 */
public interface RecordAlarmDataMapper
{
    /**
     * 查询异常数据记录
     *
     * @param objId 异常数据记录主键
     * @return 异常数据记录
     */
    public RecordAlarmData selectRecordAlarmDataByObjId(Long objId);

    /**
     * 查询异常数据记录列表
     *
     * @param recordAlarmData 异常数据记录
     * @return 异常数据记录集合
     */
    public List<RecordAlarmData> selectRecordAlarmDataList(RecordAlarmData recordAlarmData);

    /**
     * 新增异常数据记录
     *
     * @param recordAlarmData 异常数据记录
     * @return 结果
     */
    public int insertRecordAlarmData(RecordAlarmData recordAlarmData);

    /**
     * 修改异常数据记录
     *
     * @param recordAlarmData 异常数据记录
     * @return 结果
     */
    public int updateRecordAlarmData(RecordAlarmData recordAlarmData);

    /**
     * 删除异常数据记录
     *
     * @param objId 异常数据记录主键
     * @return 结果
     */
    public int deleteRecordAlarmDataByObjId(Long objId);

    /**
     * 批量删除异常数据记录
     *
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRecordAlarmDataByObjIds(Long[] objIds);
}
